
import 'package:cs_resources/generated/assets.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:plugin_platform/engine/dialog/dialog_engine.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/widget_export.dart';
import '../../../components/comments_dialog.dart';

import 'comments_input.dart';
import 'newsfeed_detail_state.dart';
import 'newsfeed_detail_page.dart';

part 'newsfeed_detail_vm.g.dart';

@riverpod
class NewsfeedDetailVm extends _$NewsfeedDetailVm {

  // 评论框信息
  final Map<String, dynamic> _textFieldInfo= {
    'value': '',
    'controller': TextEditingController(),
    'hintText': 'Please enter your comment',
    'focusNode': FocusNode(),
    'obsecure': false,
  };


  bool _needShowPlaceholder = false; //是否展示LoadingView

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,  //允许刷新
    controlFinishLoad: true,   //允许加载
  );

  NewsfeedDetailState initState() {
    return NewsfeedDetailState(
      detailInfo: {
        'id':1,
        'avator': 'https://p4.itc.cn/q_70/images03/20231121/ab826c4a7efe4c9aa93ca6e00f9e0986.jpeg',
        'title': 'William Jefferson',
        'content': 'She said YES and our lives changed.Thank you all for coming to my propose today.We hope everyone can ……[More]',
        'imageUrls': [
          'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
          'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
          'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
          'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
          'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        ],
        'time': 'June 17,2016 at 7:23 p.m.',
        'isLike': true,
        'isFollow': false,
        'likeno': 12,
      },
      list: [
        {
          'userId': 1,
          'userName': 'William Jefferson',
          'avator': 'https://iknow-pic.cdn.bcebos.com/d439b6003af33a87f27f0584d45c10385343b519',
          'time': 'June 17,2016 at 7:23 p.m.',
          'content': 'She said YES and our lives changed.Thank you all for coming to my propose today.We hope everyone can ……[More]'
        },
      ],
      commentFieldInfo: _textFieldInfo
    );
  }


  @override
  NewsfeedDetailState build(){
     final state = initState();

    // 第一次挂载后
    // WidgetsBinding.instance!.addPostFrameCallback((_) {
    // }

    // Log.d("---------444-----------------build---------------${state.detailInfo}------");
    return state;
  }

//刷新页面状态
  void changeLoadingState(LoadState loadState, String? errorMsg) {
    state = state.copyWith(
        loadingState: loadState,
        errorMessage: errorMsg
    );
  }

  // 初始化页面数据
  initPageData({int? id}) {
    Log.d("----property_news_vm-----initPageData   ${state.loadingState}");
    onRefresh(id: id);
  }

  // 上拉加载 更多
  Future loadMore({int? id}) async {
    Log.d("----property_news_vm-----loadMore");
    // await Future.delayed(const Duration(seconds: 2));
    // if(state.list.length >= state.count){
    //   return;
    // }else {
    //   int page = state.page + 1;
    //   state = state.copyWith(page: page,);
    //   getListData();
    // }
    // 检查 page 是否为 null，并初始化为 1
    int newCurPage = state.page ?? 1;
    state = state.copyWith(page: ++newCurPage);
    getListData();
  }


  // 下拉刷新
  Future onRefresh({int? id}) async {
    Log.d("----property_news_vm-----onRefresh ");

    // await Future.delayed(const Duration(seconds: 2));
    state = state.copyWith(page: 1);
    getListData();
  }

  // 重试请求
  Future retryRequest() async {
    state = state.copyWith(page: 1);
    _needShowPlaceholder = true;
    getListData();
  }


  // 获取list 列表数据
  Future getListData<T>({int? id}) async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading, null);
    }

    Log.d("加载listData数据---------------start--${state.page}---");
    //   try {
    //     //请求网络
    //     Map<String, dynamic>  params = {
    //       "page": state.page,
    //       "limit": state.limit,
    //     };
    //     Log.d("请求参数------$params");
    //     final result = await propertyNewsRepository.fetchPropertyNewsList(params);
    //     Log.d("请求完成结果------${result.data}");
    //     //校验成功失败
    //     if (result.isSuccess) {
    //       // state = state.copyWith(serverTime: result.data);
    //       state = state;
    //   handleList(listResult.data?.rows);
    //       ToastEngine.show("获取数据成功");
    //     } else {
    //   errorMessage = listResult.errorMsg;
    //   changeLoadingState(LoadState.State_Error);
    //       ToastEngine.show(result.errorMsg ?? "Network Load Error");
    //     }
    //   } catch (e) {
    //     ToastEngine.show("Error: $e");
    //   }

    await Future.delayed(const Duration(milliseconds: 1500));
    final List<Map<String, dynamic>> listData = [
      {
        'userId': 1,
        'userName': 'William Jefferson',
        'avator': 'https://img1.baidu.com/it/u=3890726495,1572750319&fm=253&fmt=auto&app=120&f=JPEG?w=500&h=500',
        'time': 'June 17,2016 at 7:23 p.m.',
        'content': 'She said YES and our lives changed.Thank you all for coming to my propose today.We hope everyone can ……[More]'
      },
      {
        'userId': 2,
        'userName': 'Ander Jackson',
        'avator': 'https://iknow-pic.cdn.bcebos.com/d439b6003af33a87f27f0584d45c10385343b519',
        'time': 'June 17,2016 at 7:23 p.m.',
        'content': 'She said YES and our lives changed.Thank you all for coming to my propose today.We hope everyone can ……[More]'
      },
    ];


    if (state.page == 1) {
      //刷新的方式
      state = state.copyWith(list: listData);
      refreshController.finishRefresh();
      // //更新展示的状态
      changeLoadingState(LoadState.State_Success, null);
    } else {
      //加载更多
      final allList = state.list;
      allList.addAll(listData);
      refreshController.finishLoad();
      state = state.copyWith(list: allList);
    }

    // 最后赋值
    _needShowPlaceholder = false;
  }


  // 点击了 comment 按钮
  handlerCommentClick(BuildContext context) async{
    BuildContext contextPage = context;
    // double height = MediaQuery.of(contextPage).size.height;
    double commentInputHeight = 150.0;
    Log.d("点击了评论按钮");
    await DialogEngine.show(
      tag: "newsFeedComments",
      position: DialogPosition.bottom,
      widget: CommentsDialog(
        isShowConfirmBtn: false,
        isShowCancelBtn: false,
        height: commentInputHeight,
        confirmAction: (){},
        cancelAction: null,
        messageBuilder: (context) {
          return Row(
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              Expanded(
                  child: Container(
                    margin: const EdgeInsets.only(left:15, right:15,top: 20, bottom: 20),
                    width: double.infinity,
                    height: commentInputHeight,
                    padding: const EdgeInsets.all(15),
                    decoration: BoxDecoration(
                        color: context.appColors.backgroundDark,
                        borderRadius: BorderRadius.circular(5),
                        boxShadow: [
                          BoxShadow(
                            color: Colors.grey.withOpacity(0.1),
                            spreadRadius:1,
                            blurRadius: 1,
                            offset: const Offset(0.5, 0.5), // changes position of shadow
                          ),
                        ]
                    ),
                    child: CommentsTextareaInput( showCounter:false, autoFocus: true),
                  ),
              ),
              Container(
                margin: const EdgeInsets.only(right: 10),
                height: commentInputHeight,
                decoration: BoxDecoration(
                  color: context.appColors.textPrimary,
                  borderRadius: BorderRadius.circular(5),
                ),
                child: Center(
                  child: IconButton(
                    icon: Icon(Icons.send, color: context.appColors.textWhite, size: 25,),
                    onPressed: (){
                      Log.d("点击了发送按钮");
                    },
                  ),
                ),
              ),
            ]
          );
        },
      ),
    );
  }

  // 点击了 Like 按钮
  bool handlerLikeClick(){
    Log.d("点击了点赞按钮");
    return true;
  }

  // 清空评论
  resetCommentField(){
    state.commentFieldInfo!['controller']!.clear();
  }
}

