import 'package:cs_resources/generated/assets.dart';
import 'package:flutter/cupertino.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';

import '../../../router/page/community_page_router.dart';
import '../../community/community_pageview_idx_data.dart';
import '../../community/community_vm.dart';
import '../garagesale_detail/garagesale_detail_page.dart';
import 'for_rent_respository.dart';
import 'for_rent_state.dart';

part 'for_rent_vm.g.dart';

@riverpod
class ForrentVm extends _$ForrentVm {
  late ForrentRepository ForrentRepositoryInstance;
  bool _needShowPlaceholder = false; //是否展示LoadingView

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,  //允许刷新
    controlFinishLoad: true,   //允许加载
  );

  ForrentState initState() {
    return ForrentState(
        list: [
          {
            'id':1,
            'goods_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
            'title': 'Electronic keyboard',
            'price': '\$66',
            'isCollection': true,
            'collection_num': 12,
            'publisher': 'William Jefferson',
            'publish_time': 'June 17,2016 at 7:23 p.m.',
            'publisrher_avator': 'https://img1.baidu.com/it/u=3890726495,1572750319&fm=253&fmt=auto&app=120&f=JPEG?w=500&h=500'
          },
          {
            'id':2,
            'goods_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
            'title': 'Electronic keyboard',
            'price': '\$88',
            'isCollection': false,
            'collection_num': 12,
            'publisher': 'William Jefferson',
            'publish_time': 'June 17,2016 at 7:23 p.m.',
            'publisher_avator': 'https://img1.baidu.com/it/u=3890726495,1572750319&fm=253&fmt=auto&app=120&f=JPEG?w=500&h=500'
          },
          {
            'id':3,
            'goods_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
            'title': 'Electronic keyboard',
            'price': '\$66',
            'isCollection': true,
            'collection_num': 12,
            'publisher': 'William Jefferson',
            'publish_time': 'June 17,2016 at 7:23 p.m.',
            'publisher_avator': 'https://img1.baidu.com/it/u=3890726495,1572750319&fm=253&fmt=auto&app=120&f=JPEG?w=500&h=500'
          },
        ]
    );
  }

  @override
  ForrentState build(){
    // 引入数据仓库
    ForrentRepositoryInstance = ref.read(forrentRepositoryProvider);
    final state = initState();
    Log.d("--------------------------build---------------------");

    return state;
  }

  //刷新页面状态
  void changeLoadingState(LoadState loadState, String? errorMsg) {
    state = state.copyWith(
        loadingState: loadState,
        errorMessage: errorMsg
    );
  }

  // 初始化页面数据
  initPageData() {
    Log.d("----for_rent_vm-----initPageData   ${state.loadingState}");
    onRefresh();
  }

  // 上拉加载 更多
  Future loadMore() async {
    bool isShowing = await ref.read(communityVmProvider.notifier).isCurrentPageViewShowing(CommunityPageViewIdxData.forRent);
    if(isShowing){
      Log.d("----for_rent_vm-----loadMore");
      // await Future.delayed(const Duration(seconds: 2));
      // if(state.list.length >= state.count){
      //   return;
      // }else {
      //   int page = state.page + 1;
      //   state = state.copyWith(page: page,);
      //   getListData();
      // }
      // 检查 page 是否为 null，并初始化为 1
      int newCurPage = state.page ?? 1;
      state = state.copyWith(page: ++newCurPage);
      getListData();
    }else {
      refreshController.finishRefresh();
    }
  }


  // 下拉刷新
  Future onRefresh() async {
    bool isShowing = await ref.read(communityVmProvider.notifier).isCurrentPageViewShowing(CommunityPageViewIdxData.forRent);
    if(isShowing){
      // 当前pageView 页面正处于显示状态
      Log.d("----for_rent_vm-----onRefresh ");
      // await Future.delayed(const Duration(seconds: 2));
      state = state.copyWith(page: 1);
      getListData();
    }else {
      refreshController.finishRefresh();
      // //更新展示的状态
      changeLoadingState(LoadState.State_Success, null);
    }
  }

  // 重试请求
  Future retryRequest() async {
    bool isShowing = await ref.read(communityVmProvider.notifier).isCurrentPageViewShowing(CommunityPageViewIdxData.forRent);
    if(isShowing){
      state = state.copyWith(page: 1);
      _needShowPlaceholder = true;
      getListData();
    }
  }


  // 获取list 列表数据
  Future getListData<T>() async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading, null);
    }

    Log.d("for_rent加载listData数据---------------start--${state.page}---");
    //   try {
    //     //请求网络
    //     Map<String, dynamic>  params = {
    //       "page": state.page,
    //       "limit": state.limit,
    //     };
    //     Log.d("请求参数------$params");
    //     final result = await propertyNewsRepository.fetchPropertyNewsList(params);
    //     Log.d("请求完成结果------${result.data}");
    //     //校验成功失败
    //     if (result.isSuccess) {
    //       // state = state.copyWith(serverTime: result.data);
    //       state = state;
    //   handleList(listResult.data?.rows);
    //       ToastEngine.show("获取数据成功");
    //     } else {
    //   errorMessage = listResult.errorMsg;
    //   changeLoadingState(LoadState.State_Error);
    //       ToastEngine.show(result.errorMsg ?? "Network Load Error");
    //     }
    //   } catch (e) {
    //     ToastEngine.show("Error: $e");
    //   }

    await Future.delayed(const Duration(milliseconds: 1500));
    final List<Map<String, dynamic>> listData = [
      {
        'id':1,
        'goods_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        'title': 'Electronic keyboard',
        'price': '\$66',
        'isCollection': true,
        'collection_num': 12,
        'publisher': 'William Jefferson',
        'publish_time': 'June 17,2016 at 7:23 p.m.',
        'publisher_avator': 'https://img1.baidu.com/it/u=3890726495,1572750319&fm=253&fmt=auto&app=120&f=JPEG?w=500&h=500'
      },
      {
        'id':2,
        'goods_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        'title': 'Electronic keyboard',
        'price': '\$88',
        'isCollection': false,
        'collection_num': 12,
        'publisher': 'William Jefferson',
        'publish_time': 'June 17,2016 at 7:23 p.m.',
        'publisher_avator': 'https://img1.baidu.com/it/u=3890726495,1572750319&fm=253&fmt=auto&app=120&f=JPEG?w=500&h=500'
      },
      {
        'id':3,
        'goods_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        'title': 'Electronic keyboard',
        'price': '\$66',
        'isCollection': true,
        'collection_num': 12,
        'publisher': 'William Jefferson',
        'publish_time': 'June 17,2016 at 7:23 p.m.',
        'publisher_avator': 'https://img1.baidu.com/it/u=3890726495,1572750319&fm=253&fmt=auto&app=120&f=JPEG?w=500&h=500'
      },
    ];

    if (state.page == 1) {
      //刷新的方式
      state = state.copyWith(list: listData);
      refreshController.finishRefresh();
      // //更新展示的状态
      changeLoadingState(LoadState.State_Success, null);
    } else {
      //加载更多
      final allList = state.list;
      allList?.addAll(listData);
      state = state.copyWith(list: allList);
      refreshController.finishLoad();

    }

    // 最后赋值
    _needShowPlaceholder = false;
  }

  // 去详情页面
  void handlerGotoDetail(id){
    Log.d("去详情页面");
    appRouter.push(GaragesaleDetailPageRoute(id: id, type: 'forRent'));
  }
}